@@ -19,7 +19,7 @@ from .app import PQtWidget
 
 class PDialog(PQtWidget, qt.QDialog, PDialogBase):
     
-    def __init__(self, manager, parent, caption, client=None,
+    def __init__(self, manager, parent, caption, client,
                  accept_buttons=('ok', 'yes'), reject_buttons=('cancel', 'no')):
         
         qt.QDialog.__init__(self, parent)
