@@ -71,3 +71,6 @@ class PPanel(PQtWidget, qt.QFrame, PPanelBase):
     def do_layout(self):
         #self._playout.addStretch(1)
         self.setLayout(self._playout)
+    
+    def remove_widget(self, widget):
+        self._playout.removeWidget(widget)
