@@ -28,9 +28,6 @@ class PQtListBoxBase(PQtSequenceWidget, qt.QListWidget):
     #def item_height(self, index):
     #    return self.itemWidget(self.item(index)).height()
     
-    def item_text(self, item):
-        return item.text()
-    
     def current_index(self):
         return self.currentRow()
     
